@@ -57,6 +57,7 @@ REST_HOST = "https://__kaisarooturl__/kgl-trade-service"
 WEBSOCKET_TRADE_HOST = "wss://__kaisarooturl__/kgl-trade-push-service/ws"
 
 openapi_scope = "wthk"
+openapi_scope = "read"
 
 MARKET_POST_URL = "https://sit-kgl.jt00000.com/kgl-stock-push-provider"
 MARKET_WS_URL = "ws://uat-stock.jt00000.com/stock"
@@ -118,7 +119,7 @@ class KaisaGateway():
     def __init__(self):
         pass
 
-    def jq_user_config(self, user_id, user_pwd, account_code, account_pwd, openapi_token, environment='paper'):
+    def jq_user_config(self, user_id, user_pwd, account_code, account_pwd, openapi_token, ip_address=None, environment='paper'):
 
         self.user_id = user_id
         self.user_pwd = user_pwd
@@ -131,6 +132,8 @@ class KaisaGateway():
 
         self.m_req_id = 0
         self.trade_req_id = 0
+        self.ip_address = ip_address
+
 
     def _update_urls(self):
 
@@ -180,13 +183,17 @@ class KaisaGateway():
             "scope": openapi_scope
         }
 
-        if appendIpAddress:
-            params["ipAddress"] = appendIpAddress
+        ipAddress = self.ip_address
+        if ipAddress:
+            params["ipAddress"] = ipAddress
 
-        headerParam = {"ipAddress":"14.154.204.168","phoneModel":"","deviceId":"","deviceToken":"","macAddress":"","channelId":"","country":"","sysVersion":"","apiVersion":"","platform":""}
+        headerParam = {"ipAddress":ipAddress,"phoneModel":"","deviceId":"","deviceToken":"","macAddress":"","channelId":"","country":"","sysVersion":"","apiVersion":"","platform":""}
         headerParam = json.dumps(headerParam)
+
+        authorization_str = "basic {}".format(self.openapi_token)
+        # print(authorization_str)
         headers = {
-            "Authorization": "basic {}".format(self.openapi_token),
+            "Authorization": authorization_str,
             "Content-Type": "application/x-www-form-urlencoded",
             "Sign": sign_,
             "Timestamp": timestamp_,
