@@ -40,7 +40,8 @@ if __name__=='__main__':
         "account_code": "9604******",
         "account_pwd": "******",
         "environment": "actual",
-        "openapi_token": my_token
+        "openapi_token": my_token,
+        "ip_address": "104.193.88.77"
     }
 
     KaisaGw = KaisaDemo()
